    <title>Web Server Integration &mdash; Transmogrify v0.1beta2 documentation</title>
# Web Server Integration #
* Lighttpd Integration
	* lighttpd.conf
	* The 404 handler script
	* Debugging the 404 Handler
* Django Development Server Integration
